EditorOptions class

Constructors

EditorOptions({Color backgroundColor = const Color.fromRGBO(0x2a, 0x2a, 0x40, 1), EditorRegionOptions? regionOptions, Color linebarColor = const Color.fromRGBO(0x3b, 0x3b, 0x4f, 1), Color linebarTextColor = Colors.white, bool showLinebar = true, bool takeFullHeight = true, bool isEditable = true, String? fontFamily})

Properties

backgroundColor ↔ Color
getter/setter pair
fontFamily ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEditable ↔ bool
getter/setter pair
linebarColor ↔ Color
getter/setter pair
linebarTextColor ↔ Color
getter/setter pair
regionOptions ↔ EditorRegionOptions?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLinebar ↔ bool
getter/setter pair
takeFullHeight ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited